Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/scores/__init__.py | 7 | 0 | 0 | 0 | 0 | 100%
src/scores/categorical/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src/scores/categorical/binary_impl.py | 37 | 0 | 0 | 4 | 0 | 100%
src/scores/categorical/multicategorical_impl.py | 58 | 0 | 0 | 24 | 0 | 100%
src/scores/continuous/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
src/scores/continuous/flip_flop_impl.py | 86 | 0 | 12 | 24 | 0 | 100%
src/scores/continuous/isoreg_impl.py | 183 | 0 | 0 | 78 | 0 | 100%
src/scores/continuous/murphy_impl.py | 88 | 0 | 0 | 20 | 0 | 100%
src/scores/continuous/quantile_loss_impl.py | 20 | 0 | 0 | 4 | 0 | 100%
src/scores/continuous/standard_impl.py | 32 | 0 | 0 | 12 | 0 | 100%
src/scores/functions.py | 16 | 0 | 6 | 2 | 0 | 100%
src/scores/probability/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
src/scores/probability/brier_impl.py | 14 | 0 | 0 | 8 | 0 | 100%
src/scores/probability/checks.py | 17 | 0 | 0 | 8 | 0 | 100%
src/scores/probability/crps_impl.py | 157 | 0 | 2 | 68 | 0 | 100%
src/scores/probability/functions.py | 95 | 0 | 0 | 38 | 1 | 99%
src/scores/probability/roc_impl.py | 27 | 0 | 0 | 8 | 0 | 100%
src/scores/processing.py | 74 | 0 | 0 | 38 | 1 | 99%
src/scores/sample_data.py | 45 | 0 | 4 | 8 | 0 | 100%
src/scores/stats/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
src/scores/stats/statistical_tests/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
src/scores/stats/statistical_tests/acovf.py | 40 | 0 | 0 | 20 | 0 | 100%
src/scores/stats/statistical_tests/diebold_mariano_impl.py | 90 | 0 | 0 | 36 | 0 | 100%
src/scores/typing.py | 7 | 0 | 0 | 0 | 0 | 100%
src/scores/utils.py | 121 | 0 | 0 | 94 | 0 | 100%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/assertions.py | 48 | 12 | 0 | 28 | 11 | 70%
tests/categorical/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/categorical/multicategorical_test_data.py | 64 | 0 | 0 | 0 | 0 | 100%
tests/categorical/test_binary.py | 57 | 0 | 0 | 12 | 0 | 100%
tests/categorical/test_multicategorical.py | 31 | 0 | 0 | 10 | 0 | 100%
tests/continuous/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/continuous/flip_flop_test_data.py | 53 | 0 | 0 | 4 | 0 | 100%
tests/continuous/isoreg_test_data.py | 50 | 0 | 0 | 0 | 0 | 100%
tests/continuous/quantile_loss_test_data.py | 25 | 0 | 0 | 0 | 0 | 100%
tests/continuous/test_flip_flop.py | 85 | 0 | 0 | 34 | 0 | 100%
tests/continuous/test_isoreg.py | 70 | 0 | 0 | 38 | 0 | 100%
tests/continuous/test_murphy.py | 156 | 0 | 0 | 42 | 1 | 99%
tests/continuous/test_quantile_loss.py | 29 | 0 | 0 | 12 | 0 | 100%
tests/continuous/test_standard.py | 253 | 3 | 0 | 42 | 6 | 97%
tests/probabilty/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/probabilty/cdf_test_data.py | 85 | 0 | 0 | 0 | 0 | 100%
tests/probabilty/crps_test_data.py | 95 | 0 | 0 | 0 | 0 | 100%
tests/probabilty/functions_test_data.py | 6 | 0 | 0 | 0 | 0 | 100%
tests/probabilty/roc_test_data.py | 12 | 0 | 0 | 0 | 0 | 100%
tests/probabilty/test_brier.py | 30 | 0 | 0 | 10 | 0 | 100%
tests/probabilty/test_crps.py | 87 | 0 | 0 | 28 | 0 | 100%
tests/probabilty/test_functions.py | 55 | 0 | 0 | 28 | 0 | 100%
tests/probabilty/test_roc.py | 25 | 0 | 0 | 6 | 0 | 100%
tests/stats/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/stats/test_acovf.py | 6 | 0 | 0 | 2 | 0 | 100%
tests/stats/test_diebold_mariano.py | 57 | 0 | 0 | 28 | 0 | 100%
tests/test_functions.py | 16 | 0 | 0 | 2 | 0 | 100%
tests/test_processing.py | 41 | 0 | 0 | 26 | 0 | 100%
tests/test_processing_data.py | 114 | 0 | 0 | 0 | 0 | 100%
tests/test_sample_data.py | 28 | 0 | 0 | 0 | 0 | 100%
tests/test_utils.py | 89 | 0 | 0 | 26 | 0 | 100%
tests/test_weights.py | 73 | 0 | 0 | 8 | 0 | 100%
tests/utils_test_data.py | 18 | 0 | 0 | 0 | 0 | 100%
Total | 2986 | 15 | 24 | 880 | 20 | 99%

No items found using the specified filter.